@@ -57,7 +57,7 @@ class Dates:
         except (TypeError, ValueError) as ex:
             raise Exception from ex
 
-    def offset(self, date_string: str | None = None, date_format:str = '%d.%m.%Y', seconds: int | None = None, minutes: int | None = None, hours: int | None = None, days: int | None = None, output_format: str = '%d.%m.%Y') -> str:
+    def offset(self, date_string: str | None = None, date_format:str = '%d.%m.%Y', seconds: int | None = None, minutes: int | None = None, hours: int | None = None, days: int | None = None, months: int | None = None, years: int | None = None, output_format: str = '%d.%m.%Y') -> str:
         """_summary_
 
         Args:
@@ -91,6 +91,10 @@ class Dates:
                 _date += datetime.timedelta(hours=hours)
             if days is not None:
                 _date += datetime.timedelta(days=days)
+            if months is not None:
+                _date += relativedelta(months=months)
+            if years is not None:
+                _date += relativedelta(years=years)
 
             return _date.strftime(output_format)
         except (NameError, ValueError, TypeError, OverflowError) as ex:
